FindDropdownChip<T> class

Dropdown que exibe o(s) item(ns) selecionado(s) como Chip do Material.

Em modo single, exibe um único Chip. Em multiSelect, exibe múltiplos Chips em um Wrap, cada um com botão de remoção via Chip.onDeleted.

Reutiliza FindDropdown internamente. Documentação do Chip: https://api.flutter.dev/flutter/material/Chip-class.html

Inheritance

Constructors

FindDropdownChip({Key? key, required FindDropdownChangedType<T?> onChanged, String? label, TextStyle? labelStyle, List<T>? items, T? selectedItem, FindDropdownFindType<T>? onFind, FindDropdownItemBuilderType<T>? dropdownItemBuilder, bool showSearchBox = true, bool showClearButton = false, FindDropdownValidationType<T>? validate, InputDecoration? searchBoxDecoration, Color? backgroundColor, TextStyle? titleStyle, WidgetBuilder? emptyBuilder, WidgetBuilder? loadingBuilder, ErrorBuilderType? errorBuilder, BoxConstraints? constraints, bool? autofocus, int? searchBoxMaxLines, int? searchBoxMinLines, ButtonBuilderType? okButtonBuilder, bool labelVisible = true, FindDropdownThemeData? theme, FindDropdownChipBuilderType<T>? chipBuilder})
const
FindDropdownChip.multiSelect({Key? key, required FindDropdownMultipleItemsChangedType<T> onChanged, String? label, TextStyle? labelStyle, List<T>? items, List<T>? selectedItems, FindDropdownFindType<T>? onFind, FindDropdownItemBuilderType<T>? dropdownItemBuilder, bool showSearchBox = true, bool showClearButton = false, FindDropdownValidationType<List<T>>? validate, InputDecoration? searchBoxDecoration, Color? backgroundColor, TextStyle? titleStyle, WidgetBuilder? emptyBuilder, WidgetBuilder? loadingBuilder, ErrorBuilderType? errorBuilder, BoxConstraints? constraints, bool? autofocus, int? searchBoxMaxLines, int? searchBoxMinLines, ButtonBuilderType? okButtonBuilder, bool labelVisible = true, FindDropdownThemeData? theme, FindDropdownChipBuilderType<T>? chipBuilder})
const

Properties

autofocus bool?
final
backgroundColor Color?
final
chipBuilder FindDropdownChipBuilderType<T>?
final
constraints BoxConstraints?
final
final
emptyBuilder WidgetBuilder?
final
errorBuilder → ErrorBuilderType?
final
hashCode int
The hash code for this object.
no setterinherited
items List<T>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
labelStyle TextStyle?
final
labelVisible bool
final
loadingBuilder WidgetBuilder?
final
multipleSelectedItems List<T>?
final
okButtonBuilder → ButtonBuilderType?
final
onChanged FindDropdownChangedType<T>?
final
onFind FindDropdownFindType<T>?
final
onMultipleItemsChanged FindDropdownMultipleItemsChangedType<T>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBoxDecoration InputDecoration?
final
searchBoxMaxLines int?
final
searchBoxMinLines int?
final
selectedItem → T?
final
showClearButton bool
final
showSearchBox bool
final
theme FindDropdownThemeData?
final
titleStyle TextStyle?
final
validate FindDropdownValidationType<T>?
final
validateMultipleItems FindDropdownValidationType<List<T>>?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() FindDropdownChipState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited